@@ -48,7 +48,7 @@
 #include "desktop.h"
 #include "directory.h"
 
-// ONLY USED IN THIS FILE
+/* ONLY USED IN THIS FILE */
 #include "fce_api_internal.h"
 
 #include "file.h"
@@ -73,12 +73,11 @@ static struct fce_history fce_history_list[FCE_HISTORY_LEN];
 *
 ****/
 
-static long get_ms_difftime (  struct timeval *tv1, struct timeval *tv2 )
+static long get_ms_difftime(struct timeval *tv1, struct timeval *tv2)
 {
-	unsigned long s = tv2->tv_sec - tv1->tv_sec;
-	long us = tv2->tv_usec - tv1->tv_usec;
-
-	return s * 1000 + us/1000;
+    unsigned long s = tv2->tv_sec - tv1->tv_sec;
+    long us = tv2->tv_usec - tv1->tv_usec;
+    return s * 1000 + us / 1000;
 }
 
 /******************************************************************************
@@ -87,80 +86,82 @@ static long get_ms_difftime (  struct timeval *tv1, struct timeval *tv2 )
 
 void fce_initialize_history(void)
 {
-	for (int i = 0; i < FCE_HISTORY_LEN; i++) {
-		memset( &fce_history_list[i], 0, sizeof(fce_history_list[i]) );
-	}
+    for (int i = 0; i < FCE_HISTORY_LEN; i++) {
+        memset(&fce_history_list[i], 0, sizeof(fce_history_list[i]));
+    }
 }
 
 bool fce_handle_coalescation(int event, const char *path)
 {
-	/* These two are used to eval our next index in history */
-	/* the history is unsorted, speed should not be a problem, length is 10 */
-	unsigned long oldest_entry = (unsigned long )((long)-1);
-	int oldest_entry_idx = -1;
-	struct timeval tv;
+    /* These two are used to eval our next index in history */
+    /* the history is unsorted, speed should not be a problem, length is 10 */
+    unsigned long oldest_entry = (unsigned long)((long) -1);
+    int oldest_entry_idx = -1;
+    struct timeval tv;
 
-	if (coalesce == 0)
-		return false;
+    if (coalesce == 0) {
+        return false;
+    }
 
-	/* After a file creation *ALWAYS* a file modification is produced */
-	if ((event == FCE_FILE_CREATE) && (coalesce & FCE_COALESCE_CREATE))
+    /* After a file creation *ALWAYS* a file modification is produced */
+    if ((event == FCE_FILE_CREATE) && (coalesce & FCE_COALESCE_CREATE)) {
         return true;
+    }
 
-	/* get timestamp */
-	gettimeofday(&tv, 0);
+    /* get timestamp */
+    gettimeofday(&tv, 0);
 
-	/* Now detect events in the very near history */
-	for (int i = 0; i < FCE_HISTORY_LEN; i++) {
-		struct fce_history *fh = &fce_history_list[i];
+    /* Now detect events in the very near history */
+    for (int i = 0; i < FCE_HISTORY_LEN; i++) {
+        struct fce_history *fh = &fce_history_list[i];
 
-		/* Not inited ? */
-		if (fh->fce_h_tv.tv_sec == 0) {
-			/* we can use it for new elements */
-			oldest_entry = 0;
-			oldest_entry_idx = i;
-			continue;
-		}
+        /* Not inited ? */
+        if (fh->fce_h_tv.tv_sec == 0) {
+            /* we can use it for new elements */
+            oldest_entry = 0;
+            oldest_entry_idx = i;
+            continue;
+        }
 
-		/* Too old ? */
-		if (get_ms_difftime(&fh->fce_h_tv, &tv ) > MAX_COALESCE_TIME_MS) {
-			/* Invalidate entry */
-			fh->fce_h_tv.tv_sec = 0;
-			oldest_entry = 0;
-			oldest_entry_idx = i;			
-			continue;
-		}
+        /* Too old ? */
+        if (get_ms_difftime(&fh->fce_h_tv, &tv) > MAX_COALESCE_TIME_MS) {
+            /* Invalidate entry */
+            fh->fce_h_tv.tv_sec = 0;
+            oldest_entry = 0;
+            oldest_entry_idx = i;
+            continue;
+        }
 
+        /* If we find a parent dir wich was created we are done */
+        if ((coalesce & FCE_COALESCE_CREATE) && (fh->fce_h_event == FCE_DIR_CREATE)) {
+            /* Parent dir ? */
+            if (!strncmp(fh->fce_h_path, path, strlen(fh->fce_h_path))) {
+                return true;
+            }
+        }
 
-		/* If we find a parent dir wich was created we are done */
-		if ((coalesce & FCE_COALESCE_CREATE) && (fh->fce_h_event == FCE_DIR_CREATE)) {
-			/* Parent dir ? */
-			if (!strncmp(fh->fce_h_path, path, strlen(fh->fce_h_path)))
-				return true;
-		}
+        /* If we find a parent dir we should be DELETED we are done */
+        if ((coalesce & FCE_COALESCE_DELETE)
+                && (event == FCE_FILE_DELETE || event == FCE_DIR_DELETE)) {
+            /* Parent dir ? */
+            if (!strncmp(fh->fce_h_path, path, strlen(fh->fce_h_path))) {
+                return true;
+            }
+        }
 
-		/* If we find a parent dir we should be DELETED we are done */
-		if ((coalesce & FCE_COALESCE_DELETE)
-            && (event == FCE_FILE_DELETE || event == FCE_DIR_DELETE)) {
-			/* Parent dir ? */
-			if (!strncmp(fh->fce_h_path, path, strlen(fh->fce_h_path)))
-				return true;
-		}
+        /* Detect oldest entry for next new entry */
+        if (oldest_entry_idx == -1 || fh->fce_h_tv.tv_sec < oldest_entry) {
+            oldest_entry = fh->fce_h_tv.tv_sec;
+            oldest_entry_idx = i;
+        }
+    }
 
-		/* Detect oldest entry for next new entry */
-		if (oldest_entry_idx == -1 || fh->fce_h_tv.tv_sec < oldest_entry) {
-			oldest_entry = fh->fce_h_tv.tv_sec;
-			oldest_entry_idx = i;
-		}
-	}
-
-	/* We have a new entry for the history, register it */
-	fce_history_list[oldest_entry_idx].fce_h_tv = tv;
-	fce_history_list[oldest_entry_idx].fce_h_event = event;
+    /* We have a new entry for the history, register it */
+    fce_history_list[oldest_entry_idx].fce_h_tv = tv;
+    fce_history_list[oldest_entry_idx].fce_h_event = event;
     strncpy(fce_history_list[oldest_entry_idx].fce_h_path, path, MAXPATHLEN);
-
-	/* we have to handle this event */
-	return false;
+    /* we have to handle this event */
+    return false;
 }
 
 /*
@@ -173,8 +174,9 @@ int fce_set_coalesce(const char *opt)
     char *e;
     char *p;
 
-    if (opt == NULL)
+    if (opt == NULL) {
         return AFPERR_PARAM;
+    }
 
     e = strdup(opt);
 
@@ -189,7 +191,6 @@ int fce_set_coalesce(const char *opt)
     }
 
     free(e);
-
     return AFP_OK;
 }
 
