@@ -1,6 +1,4 @@
 /*
- * $Id: file.h,v 1.6.14.1 2004/06/09 01:25:53 bfernhomberg Exp $
- *
  * Copyright (c) 1990,1991 Regents of The University of Michigan.
  * All Rights Reserved.  See COPYRIGHT.
  */
@@ -8,7 +6,7 @@
 #ifndef PAPD_FILE_H
 #define PAPD_FILE_H 1
 
-#include <sys/cdefs.h>
+#include <sys/types.h>
 
 struct papfile {
     int			pf_state;
@@ -25,6 +23,7 @@ struct papfile {
 #define PF_QUERY	(1<<2)
 #define PF_STW		(1<<3)
 #define PF_TRANSLATE	(1<<4)
+#define PF_FONT_QUERY	(1<<5)
 
 #define CONSUME( pf, len )  {   (pf)->pf_data += (len); \
 				(pf)->pf_datalen -= (len); \
@@ -36,9 +35,10 @@ struct papfile {
 
 #define PF_MORESPACE	1024
 
-int markline __P(( struct papfile *, char **, int *, int * ));
-void morespace __P(( struct papfile *, const char *, int ));
-void append __P(( struct papfile *, const char *, int ));
-void spoolerror __P(( struct papfile *, char * ));
+int markline(struct papfile *, char **, int *, int *);
+void morespace(struct papfile *, const char *, int);
+void append(struct papfile *, const char *, int);
+void spoolerror(struct papfile *, char *);
+void spoolreply(struct papfile *, char *);
 
 #endif /* PAPD_FILE_H */
