@@ -45,7 +45,8 @@ static void dsi_header_pack_reply(const DSI *dsi, char *buf)
     buf[0] = dsi->header.dsi_flags;
     buf[1] = dsi->header.dsi_command;
     memcpy(buf + 2, &dsi->header.dsi_requestID, sizeof(dsi->header.dsi_requestID));
-    memcpy(buf + 4, &dsi->header.dsi_data.dsi_code, sizeof(dsi->header.dsi_data.dsi_code));
+    memcpy(buf + 4, &dsi->header.dsi_data.dsi_code,
+           sizeof(dsi->header.dsi_data.dsi_code));
     memcpy(buf + 8, &dsi->header.dsi_len, sizeof(dsi->header.dsi_len));
     memcpy(buf + 12, &dsi->header.dsi_reserved, sizeof(dsi->header.dsi_reserved));
 }
@@ -65,40 +66,46 @@ static int dsi_peek(DSI *dsi)
     int    len;
     int    maxfd;
     int    ret;
-
     LOG(log_debug, logtype_dsi, "dsi_peek");
-
     maxfd = dsi->socket + 1;
 
     while (1) {
         if (dsi->socket == -1)
             /* e.g. dsi_disconnect() might have disconnected us */
+        {
             return -1;
+        }
+
         FD_ZERO(&readfds);
         FD_ZERO(&writefds);
 
         if (dsi->eof < dsi->end) {
             /* space in read buffer */
-            FD_SET( dsi->socket, &readfds);
+            FD_SET(dsi->socket, &readfds);
         } else {
             if (!warned) {
                 warned = 1;
-                LOG(log_note, logtype_dsi, "dsi_peek: readahead buffer is full, possibly increase -dsireadbuf option");
-                LOG(log_note, logtype_dsi, "dsi_peek: dsireadbuf: %d, DSI quantum: %d, effective buffer size: %d",
+                LOG(log_note, logtype_dsi,
+                    "dsi_peek: readahead buffer is full, possibly increase -dsireadbuf option");
+                LOG(log_note, logtype_dsi,
+                    "dsi_peek: dsireadbuf: %d, DSI quantum: %d, effective buffer size: %d",
                     dsi->dsireadbuf,
                     dsi->server_quantum ? dsi->server_quantum : DSI_SERVQUANT_DEF,
                     dsi->end - dsi->buffer);
             }
         }
 
-        FD_SET( dsi->socket, &writefds);
+        FD_SET(dsi->socket, &writefds);
 
         /* No timeout: if there's nothing to read nor nothing to write,
          * we've got nothing to do at all */
-        if ((ret = select( maxfd, &readfds, &writefds, NULL, NULL)) <= 0) {
+        if ((ret = select(maxfd, &readfds, &writefds, NULL, NULL)) <= 0) {
             if (ret == -1 && errno == EINTR)
                 /* we might have been interrupted by out timer, so restart select */
+            {
                 continue;
+            }
+
             /* give up */
             LOG(log_error, logtype_dsi, "dsi_peek: unexpected select return: %d %s",
                 ret, ret < 0 ? strerror(errno) : "");
@@ -120,13 +127,17 @@ static int dsi_peek(DSI *dsi)
                     LOG(log_error, logtype_dsi, "dsi_peek: EOF");
                     return -1;
                 }
+
                 LOG(log_error, logtype_dsi, "dsi_peek: read: %s", strerror(errno));
-                if (errno == EAGAIN)
+
+                if (errno == EAGAIN) {
                     continue;
+                }
+
                 return -1;
             }
-            LOG(log_debug, logtype_dsi, "dsi_peek: read %d bytes", len);
 
+            LOG(log_debug, logtype_dsi, "dsi_peek: read %d bytes", len);
             dsi->eof += len;
         }
     }
@@ -143,10 +154,11 @@ static size_t from_buf(DSI *dsi, uint8_t *buf, size_t count)
 
     if (dsi->buffer == NULL)
         /* afpd master has no DSI buffering */
+    {
         return 0;
+    }
 
     LOG(log_maxdebug, logtype_dsi, "from_buf: %u bytes", count);
-
     nbe = dsi->eof - dsi->start;
 
     if (nbe > 0) {
@@ -154,13 +166,14 @@ static size_t from_buf(DSI *dsi, uint8_t *buf, size_t count)
         memcpy(buf, dsi->start, nbe);
         dsi->start += nbe;
 
-        if (dsi->eof == dsi->start)
+        if (dsi->eof == dsi->start) {
             dsi->start = dsi->eof = dsi->buffer;
+        }
     }
 
-    LOG(log_debug, logtype_dsi, "from_buf(read: %u, unread:%u , space left: %u): returning %u",
+    LOG(log_debug, logtype_dsi,
+        "from_buf(read: %u, unread:%u , space left: %u): returning %u",
         dsi->start - dsi->buffer, dsi->eof - dsi->start, dsi->end - dsi->eof, nbe);
-
     return nbe;
 }
 
@@ -175,20 +188,20 @@ static size_t from_buf(DSI *dsi, uint8_t *buf, size_t count)
 static ssize_t buf_read(DSI *dsi, uint8_t *buf, size_t count)
 {
     ssize_t len;
-
     LOG(log_maxdebug, logtype_dsi, "buf_read(%u bytes)", count);
 
-    if (!count)
+    if (!count) {
         return 0;
+    }
 
     len = from_buf(dsi, buf, count); /* 1. */
-    if (len)
-        return len;             /* 2. */
+
+    if (len) {
+        return len;    /* 2. */
+    }
 
     len = readt(dsi->socket, buf, count, 0, 0); /* 3. */
-
     LOG(log_maxdebug, logtype_dsi, "buf_read(%u bytes): got: %d", count, len);
-
     return len;
 }
 
@@ -196,48 +209,55 @@ static ssize_t buf_read(DSI *dsi, uint8_t *buf, size_t count)
  * Get "length" bytes from buffer and/or socket. In order to avoid frequent small reads
  * this tries to read larger chunks (8192 bytes) into a buffer.
  */
-static size_t dsi_buffered_stream_read(DSI *dsi, uint8_t *data, const size_t length)
+static size_t dsi_buffered_stream_read(DSI *dsi, uint8_t *data,
+                                       const size_t length)
 {
-  size_t len;
-  size_t buflen;
+    size_t len;
+    size_t buflen;
+    LOG(log_maxdebug, logtype_dsi, "dsi_buffered_stream_read: %u bytes", length);
+    /* read from buffer dsi->buffer */
+    len = from_buf(dsi, data, length);
+    dsi->read_count += len;
 
-  LOG(log_maxdebug, logtype_dsi, "dsi_buffered_stream_read: %u bytes", length);
+    /* got enough bytes from there ? */
+    if (len == length) {
+        /* yes */
+        return len;
+    }
 
-  len = from_buf(dsi, data, length); /* read from buffer dsi->buffer */
-  dsi->read_count += len;
-  if (len == length) {          /* got enough bytes from there ? */
-      return len;               /* yes */
-  }
+    /* fill the buffer with 8192 bytes or until buffer is full */
+    buflen = MIN(8192, dsi->end - dsi->eof);
 
-  /* fill the buffer with 8192 bytes or until buffer is full */
-  buflen = MIN(8192, dsi->end - dsi->eof);
-  if (buflen > 0) {
-      ssize_t ret;
-      ret = recv(dsi->socket, dsi->eof, buflen, 0);
-      if (ret > 0)
-          dsi->eof += ret;
-  }
+    if (buflen > 0) {
+        ssize_t ret;
+        ret = recv(dsi->socket, dsi->eof, buflen, 0);
 
-  /* now get the remaining data */
-  if ((buflen = dsi_stream_read(dsi, data + len, length - len)) != length - len)
-      return 0;
-  len += buflen;
+        if (ret > 0) {
+            dsi->eof += ret;
+        }
+    }
 
-  return len;
+    /* now get the remaining data */
+    if ((buflen = dsi_stream_read(dsi, data + len, length - len)) != length - len) {
+        return 0;
+    }
+
+    len += buflen;
+    return len;
 }
 
 /* ---------------------------------------
 */
 static void block_sig(DSI *dsi)
 {
-  dsi->in_write++;
+    dsi->in_write++;
 }
 
 /* ---------------------------------------
 */
 static void unblock_sig(DSI *dsi)
 {
-  dsi->in_write--;
+    dsi->in_write--;
 }
 
 /*********************************************************************************
@@ -260,8 +280,11 @@ int dsi_disconnect(DSI *dsi)
     dsi->proto_close(dsi);          /* 1 */
     dsi->flags &= ~(DSI_SLEEPING | DSI_EXTSLEEP); /* 2 */
     dsi->flags |= DSI_DISCONNECTED;
-    if (geteuid() == 0)
+
+    if (geteuid() == 0) {
         return -1;
+    }
+
     return 0;
 }
 
@@ -271,68 +294,73 @@ int dsi_disconnect(DSI *dsi)
  * specified. */
 ssize_t dsi_stream_write(DSI *dsi, void *data, const size_t length, int mode)
 {
-  size_t written;
-  ssize_t len;
-  unsigned int flags;
+    size_t written;
+    ssize_t len;
+    unsigned int flags;
+    dsi->in_write++;
+    written = 0;
+    LOG(log_maxdebug, logtype_dsi, "dsi_stream_write(send: %zd bytes): START",
+        length);
 
-  dsi->in_write++;
-  written = 0;
+    if (dsi->flags & DSI_DISCONNECTED) {
+        return -1;
+    }
 
-  LOG(log_maxdebug, logtype_dsi, "dsi_stream_write(send: %zd bytes): START", length);
+    if (mode & DSI_MSG_MORE) {
+        flags = MSG_MORE;
+    } else {
+        flags = 0;
+    }
 
-  if (dsi->flags & DSI_DISCONNECTED)
-      return -1;
+    while (written < length) {
+        len = send(dsi->socket, (uint8_t *) data + written, length - written, flags);
 
-  if (mode & DSI_MSG_MORE)
-      flags = MSG_MORE;
-  else
-      flags = 0;
+        if (len >= 0) {
+            written += len;
+            continue;
+        }
 
-  while (written < length) {
-      len = send(dsi->socket, (uint8_t *) data + written, length - written, flags);
-      if (len >= 0) {
-          written += len;
-          continue;
-      }
+        if (errno == EINTR) {
+            continue;
+        }
 
-      if (errno == EINTR)
-          continue;
+        if (errno == EAGAIN || errno == EWOULDBLOCK) {
+            LOG(log_debug, logtype_dsi, "dsi_stream_write: send: %s", strerror(errno));
 
-      if (errno == EAGAIN || errno == EWOULDBLOCK) {
-          LOG(log_debug, logtype_dsi, "dsi_stream_write: send: %s", strerror(errno));
+            if (mode == DSI_NOWAIT && written == 0) {
+                /* DSI_NOWAIT is used by attention give up in this case. */
+                written = -1;
+                goto exit;
+            }
 
-          if (mode == DSI_NOWAIT && written == 0) {
-              /* DSI_NOWAIT is used by attention give up in this case. */
-              written = -1;
-              goto exit;
-          }
+            /* Try to read sth. in order to break up possible deadlock */
+            if (dsi_peek(dsi) != 0) {
+                written = -1;
+                goto exit;
+            }
 
-          /* Try to read sth. in order to break up possible deadlock */
-          if (dsi_peek(dsi) != 0) {
-              written = -1;
-              goto exit;
-          }
-          /* Now try writing again */
-          continue;
-      }
+            /* Now try writing again */
+            continue;
+        }
 
-      LOG(log_error, logtype_dsi, "dsi_stream_write: %s", strerror(errno));
-      written = -1;
-      goto exit;
-  }
-
-  dsi->write_count += written;
-  LOG(log_maxdebug, logtype_dsi, "dsi_stream_write(send: %zd bytes): END", length);
+        LOG(log_error, logtype_dsi, "dsi_stream_write: %s", strerror(errno));
+        written = -1;
+        goto exit;
+    }
 
+    dsi->write_count += written;
+    LOG(log_maxdebug, logtype_dsi, "dsi_stream_write(send: %zd bytes): END",
+        length);
 exit:
-  dsi->in_write--;
-  return written;
+    dsi->in_write--;
+    return written;
 }
 
 /* ---------------------------------
 */
 #ifdef WITH_SENDFILE
-ssize_t dsi_stream_read_file(DSI *dsi, const int fromfd, off_t offset, const size_t length, const int err)
+ssize_t dsi_stream_read_file(DSI *dsi, const int fromfd, off_t offset,
+                             const size_t length, const int err)
 {
     int ret = 0;
     size_t written = 0;
@@ -355,20 +383,19 @@ ssize_t dsi_stream_read_file(DSI *dsi, const int fromfd, off_t offset, const siz
     hdr.trl_cnt = 0;
     hdrp = &hdr;
 #endif
+    LOG(log_maxdebug, logtype_dsi, "dsi_stream_read_file(off: %jd, len: %zu)",
+        (intmax_t)offset, length);
 
-    LOG(log_maxdebug, logtype_dsi, "dsi_stream_read_file(off: %jd, len: %zu)", (intmax_t)offset, length);
-
-    if (dsi->flags & DSI_DISCONNECTED)
+    if (dsi->flags & DSI_DISCONNECTED) {
         return -1;
+    }
 
     dsi->in_write++;
-
     dsi->flags |= DSI_NOREPLY;
     dsi->header.dsi_flags = DSIFL_REPLY;
     dsi->header.dsi_len = htonl(length);
     dsi->header.dsi_data.dsi_code = htonl(err);
     dsi_header_pack_reply(dsi, block);
-
 #ifdef HAVE_SENDFILEV
     total += DSI_BLOCKSIZ;
     sfvcnt = 2;
@@ -395,11 +422,15 @@ ssize_t dsi_stream_read_file(DSI *dsi, const int fromfd, off_t offset, const siz
         len = sendfilev(dsi->socket, vec, sfvcnt, &nwritten);
 #elif defined(FREEBSD)
         len = sendfile(fromfd, dsi->socket, pos, total - written, hdrp, &nwritten, 0);
-        if (len == 0)
+
+        if (len == 0) {
             len = nwritten;
+        }
+
 #else
         len = sys_sendfile(dsi->socket, fromfd, &pos, total - written);
 #endif
+
         if (len < 0) {
             switch (errno) {
             case EINTR:
@@ -408,18 +439,22 @@ ssize_t dsi_stream_read_file(DSI *dsi, const int fromfd, off_t offset, const siz
 #if defined(HAVE_SENDFILEV) || defined(FREEBSD)
                 len = (size_t)nwritten;
 #elif defined(SOLARIS)
+
                 if (pos > offset) {
                     /* we actually have sent sth., adjust counters and keep trying */
                     len = pos - offset;
                     offset = pos;
                 }
+
 #endif /* HAVE_SENDFILEV */
 
                 if (dsi_peek(dsi) != 0) {
                     ret = -1;
                     goto exit;
                 }
+
                 break;
+
             default:
                 LOG(log_error, logtype_dsi, "dsi_stream_read_file: %s", strerror(errno));
                 ret = -1;
@@ -430,18 +465,21 @@ ssize_t dsi_stream_read_file(DSI *dsi, const int fromfd, off_t offset, const siz
             ret = -1;
             goto exit;
         }
+
 #ifdef HAVE_SENDFILEV
+
         if (sfvcnt == 2 && len >= vec[0].sfv_len) {
             vec[1].sfv_off += len - vec[0].sfv_len;
             vec[1].sfv_len -= len - vec[0].sfv_len;
-
             vec[0] = vec[1];
             sfvcnt = 1;
         } else {
             vec[0].sfv_off += len;
             vec[0].sfv_len -= len;
         }
+
 #elif defined(FREEBSD)
+
         if (hdrp) {
             if (len >= iovec.iov_len) {
                 hdrp = NULL;
@@ -452,21 +490,25 @@ ssize_t dsi_stream_read_file(DSI *dsi, const int fromfd, off_t offset, const siz
                 len = 0;
             }
         }
+
         pos += len;
 #endif  /* HAVE_SENDFILEV */
         LOG(log_maxdebug, logtype_dsi, "dsi_stream_read_file: wrote: %zd", len);
         written += len;
     }
+
 #ifdef HAVE_SENDFILEV
     written -= DSI_BLOCKSIZ;
 #endif
     dsi->write_count += written;
-
 exit:
     dsi->in_write--;
     LOG(log_maxdebug, logtype_dsi, "dsi_stream_read_file: written: %zd", written);
-    if (ret != 0)
+
+    if (ret != 0) {
         return -1;
+    }
+
     return written;
 }
 #endif
@@ -480,39 +522,43 @@ exit:
  */
 size_t dsi_stream_read(DSI *dsi, void *data, const size_t length)
 {
-  size_t stored;
-  ssize_t len;
+    size_t stored;
+    ssize_t len;
 
-  if (dsi->flags & DSI_DISCONNECTED)
-      return 0;
+    if (dsi->flags & DSI_DISCONNECTED) {
+        return 0;
+    }
 
-  LOG(log_maxdebug, logtype_dsi, "dsi_stream_read(%u bytes)", length);
+    LOG(log_maxdebug, logtype_dsi, "dsi_stream_read(%u bytes)", length);
+    stored = 0;
 
-  stored = 0;
-  while (stored < length) {
-      len = buf_read(dsi, (uint8_t *) data + stored, length - stored);
-      if (len == -1 && (errno == EINTR || errno == EAGAIN)) {
-          LOG(log_maxdebug, logtype_dsi, "dsi_stream_read: select read loop");
-          continue;
-      } else if (len > 0) {
-          stored += len;
-      } else { /* eof or error */
-          /* don't log EOF error if it's just after connect (OSX 10.3 probe) */
-          if (len || stored || dsi->read_count) {
-              if (! (dsi->flags & DSI_DISCONNECTED)) {
-                  LOG(log_error, logtype_dsi, "dsi_stream_read: len:%d, %s",
-                      len, (len < 0) ? strerror(errno) : "unexpected EOF");
-              }
-              return 0;
-          }
-          break;
-      }
-  }
+    while (stored < length) {
+        len = buf_read(dsi, (uint8_t *) data + stored, length - stored);
 
-  dsi->read_count += stored;
+        if (len == -1 && (errno == EINTR || errno == EAGAIN)) {
+            LOG(log_maxdebug, logtype_dsi, "dsi_stream_read: select read loop");
+            continue;
+        } else if (len > 0) {
+            stored += len;
+        } else { /* eof or error */
+            /* don't log EOF error if it's just after connect (OSX 10.3 probe) */
+            if (len || stored || dsi->read_count) {
+                if (!(dsi->flags & DSI_DISCONNECTED || dsi->flags & DSI_AFP_LOGGED_OUT)) {
+                    LOG(log_error, logtype_dsi, "dsi_stream_read: len:%d, %s",
+                        len, (len < 0) ? strerror(errno) : "unexpected EOF");
+                }
 
-  LOG(log_maxdebug, logtype_dsi, "dsi_stream_read(%u bytes): got: %u", length, stored);
-  return stored;
+                return 0;
+            }
+
+            break;
+        }
+    }
+
+    dsi->read_count += stored;
+    LOG(log_maxdebug, logtype_dsi, "dsi_stream_read(%u bytes): got: %u", length,
+        stored);
+    return stored;
 }
 
 /* ---------------------------------------
@@ -521,70 +567,75 @@ size_t dsi_stream_read(DSI *dsi, void *data, const size_t length)
  */
 int dsi_stream_send(DSI *dsi, void *buf, size_t length)
 {
-  char block[DSI_BLOCKSIZ];
-  struct iovec iov[2];
-  int iovecs = 2;
-  size_t towrite;
-  ssize_t len;
+    char block[DSI_BLOCKSIZ];
+    struct iovec iov[2];
+    int iovecs = 2;
+    size_t towrite;
+    ssize_t len;
+    LOG(log_maxdebug, logtype_dsi, "dsi_stream_send(%u bytes): START", length);
 
-  LOG(log_maxdebug, logtype_dsi, "dsi_stream_send(%u bytes): START", length);
+    if (dsi->flags & DSI_DISCONNECTED) {
+        return 0;
+    }
 
-  if (dsi->flags & DSI_DISCONNECTED)
-      return 0;
+    dsi_header_pack_reply(dsi, block);
 
-  dsi_header_pack_reply(dsi, block);
+    if (!length) { /* just write the header */
+        LOG(log_maxdebug, logtype_dsi, "dsi_stream_send(%u bytes): DSI header, no data",
+            sizeof(block));
+        length = (dsi_stream_write(dsi, block, sizeof(block), 0) == sizeof(block));
+        return length; /* really 0 on failure, 1 on success */
+    }
 
-  if (!length) { /* just write the header */
-      LOG(log_maxdebug, logtype_dsi, "dsi_stream_send(%u bytes): DSI header, no data", sizeof(block));
-    length = (dsi_stream_write(dsi, block, sizeof(block), 0) == sizeof(block));
-    return length; /* really 0 on failure, 1 on success */
-  }
+    /* block signals */
+    block_sig(dsi);
+    iov[0].iov_base = block;
+    iov[0].iov_len = sizeof(block);
+    iov[1].iov_base = buf;
+    iov[1].iov_len = length;
+    towrite = sizeof(block) + length;
+    dsi->write_count += towrite;
 
-  /* block signals */
-  block_sig(dsi);
-  iov[0].iov_base = block;
-  iov[0].iov_len = sizeof(block);
-  iov[1].iov_base = buf;
-  iov[1].iov_len = length;
+    while (towrite > 0) {
+        if (((len = writev(dsi->socket, iov, iovecs)) == -1 && errno == EINTR)
+                || (len == 0)) {
+            continue;
+        }
 
-  towrite = sizeof(block) + length;
-  dsi->write_count += towrite;
-  while (towrite > 0) {
-      if (((len = writev(dsi->socket, iov, iovecs)) == -1 && errno == EINTR) || (len == 0))
-          continue;
+        if ((size_t)len == towrite) { /* wrote everything out */
+            break;
+        } else if (len < 0) { /* error */
+            if (errno == EAGAIN || errno == EWOULDBLOCK) {
+                if (dsi_peek(dsi) == 0) {
+                    continue;
+                }
+            }
 
-      if ((size_t)len == towrite) /* wrote everything out */
-          break;
-      else if (len < 0) { /* error */
-          if (errno == EAGAIN || errno == EWOULDBLOCK) {
-              if (dsi_peek(dsi) == 0) {
-                  continue;
-              }
-          }
-          LOG(log_error, logtype_dsi, "dsi_stream_send: %s", strerror(errno));
-          unblock_sig(dsi);
-          return 0;
-      }
+            LOG(log_error, logtype_dsi, "dsi_stream_send: %s", strerror(errno));
+            unblock_sig(dsi);
+            return 0;
+        }
 
-      towrite -= len;
-      if (towrite > length) { /* skip part of header */
-          iov[0].iov_base = (char *) iov[0].iov_base + len;
-          iov[0].iov_len -= len;
-      } else { /* skip to data */
-          if (iovecs == 2) {
-              iovecs = 1;
-              len -= iov[0].iov_len;
-              iov[0] = iov[1];
-          }
-          iov[0].iov_base = (char *) iov[0].iov_base + len;
-          iov[0].iov_len -= len;
-      }
-  }
+        towrite -= len;
 
-  LOG(log_maxdebug, logtype_dsi, "dsi_stream_send(%u bytes): END", length);
+        if (towrite > length) { /* skip part of header */
+            iov[0].iov_base = (char *) iov[0].iov_base + len;
+            iov[0].iov_len -= len;
+        } else { /* skip to data */
+            if (iovecs == 2) {
+                iovecs = 1;
+                len -= iov[0].iov_len;
+                iov[0] = iov[1];
+            }
 
-  unblock_sig(dsi);
-  return 1;
+            iov[0].iov_base = (char *) iov[0].iov_base + len;
+            iov[0].iov_len -= len;
+        }
+    }
+
+    LOG(log_maxdebug, logtype_dsi, "dsi_stream_send(%u bytes): END", length);
+    unblock_sig(dsi);
+    return 1;
 }
 
 
@@ -597,45 +648,55 @@ int dsi_stream_send(DSI *dsi, void *buf, size_t length)
  */
 int dsi_stream_receive(DSI *dsi)
 {
-  char block[DSI_BLOCKSIZ];
+    char block[DSI_BLOCKSIZ];
+    LOG(log_maxdebug, logtype_dsi, "dsi_stream_receive: START");
 
-  LOG(log_maxdebug, logtype_dsi, "dsi_stream_receive: START");
+    if (dsi->flags & DSI_DISCONNECTED) {
+        return 0;
+    }
 
-  if (dsi->flags & DSI_DISCONNECTED)
-      return 0;
+    /* read in the header */
+    if (dsi_buffered_stream_read(dsi, (uint8_t *)block,
+                                 sizeof(block)) != sizeof(block)) {
+        return 0;
+    }
 
-  /* read in the header */
-  if (dsi_buffered_stream_read(dsi, (uint8_t *)block, sizeof(block)) != sizeof(block))
-    return 0;
+    dsi->header.dsi_flags = block[0];
+    dsi->header.dsi_command = block[1];
 
-  dsi->header.dsi_flags = block[0];
-  dsi->header.dsi_command = block[1];
+    if (dsi->header.dsi_command == 0) {
+        return 0;
+    }
 
-  if (dsi->header.dsi_command == 0)
-      return 0;
+    memcpy(&dsi->header.dsi_requestID, block + 2,
+           sizeof(dsi->header.dsi_requestID));
+    memcpy(&dsi->header.dsi_data.dsi_doff, block + 4,
+           sizeof(dsi->header.dsi_data.dsi_doff));
+    dsi->header.dsi_data.dsi_doff = htonl(dsi->header.dsi_data.dsi_doff);
+    memcpy(&dsi->header.dsi_len, block + 8, sizeof(dsi->header.dsi_len));
+    memcpy(&dsi->header.dsi_reserved, block + 12, sizeof(dsi->header.dsi_reserved));
+    dsi->clientID = ntohs(dsi->header.dsi_requestID);
+    /* make sure we don't over-write our buffers. */
+    dsi->cmdlen = MIN(ntohl(dsi->header.dsi_len), dsi->server_quantum);
+    dsi->header.dsi_data.dsi_doff = MIN(dsi->header.dsi_data.dsi_doff,
+                                        dsi->server_quantum);
 
-  memcpy(&dsi->header.dsi_requestID, block + 2, sizeof(dsi->header.dsi_requestID));
-  memcpy(&dsi->header.dsi_data.dsi_doff, block + 4, sizeof(dsi->header.dsi_data.dsi_doff));
-  dsi->header.dsi_data.dsi_doff = htonl(dsi->header.dsi_data.dsi_doff);
-  memcpy(&dsi->header.dsi_len, block + 8, sizeof(dsi->header.dsi_len));
+    /* Work around bug in ASC 3.7.x when client sends a zero byte AFPWrite() */
+    if (dsi->header.dsi_command == DSIFUNC_WRITE
+            && !(dsi->header.dsi_data.dsi_doff)) {
+        dsi->header.dsi_data.dsi_doff = 12;
+    }
 
-  memcpy(&dsi->header.dsi_reserved, block + 12, sizeof(dsi->header.dsi_reserved));
-  dsi->clientID = ntohs(dsi->header.dsi_requestID);
+    /* Receiving DSIWrite data is done in AFP function, not here */
+    if (dsi->header.dsi_data.dsi_doff) {
+        LOG(log_maxdebug, logtype_dsi, "dsi_stream_receive: write request");
+        dsi->cmdlen = dsi->header.dsi_data.dsi_doff;
+    }
 
-  /* make sure we don't over-write our buffers. */
-  dsi->cmdlen = MIN(ntohl(dsi->header.dsi_len), dsi->server_quantum);
-  dsi->header.dsi_data.dsi_doff = MIN(dsi->header.dsi_data.dsi_doff, dsi->server_quantum);
+    if (dsi_stream_read(dsi, dsi->commands, dsi->cmdlen) != dsi->cmdlen) {
+        return 0;
+    }
 
-  /* Receiving DSIWrite data is done in AFP function, not here */
-  if (dsi->header.dsi_data.dsi_doff) {
-      LOG(log_maxdebug, logtype_dsi, "dsi_stream_receive: write request");
-      dsi->cmdlen = dsi->header.dsi_data.dsi_doff;
-  }
-
-  if (dsi_stream_read(dsi, dsi->commands, dsi->cmdlen) != dsi->cmdlen)
-    return 0;
-
-  LOG(log_debug, logtype_dsi, "dsi_stream_receive: DSI cmdlen: %zd", dsi->cmdlen);
-
-  return block[1];
+    LOG(log_debug, logtype_dsi, "dsi_stream_receive: DSI cmdlen: %zd", dsi->cmdlen);
+    return block[1];
 }
