@@ -21,32 +21,34 @@
 
 int netddp_open(struct sockaddr_at *addr, struct sockaddr_at *bridge)
 {
-
 #ifdef NO_DDP
     return -1;
 #else /* !NO_DDP */
-
     int s;
     socklen_t len;
 
-    if ((s = socket( AF_APPLETALK, SOCK_DGRAM, 0 )) < 0) 
-	return -1;
-    
-    if (!addr)
-	return s;
+    if ((s = socket(AF_APPLETALK, SOCK_DGRAM, 0)) < 0) {
+        return -1;
+    }
+
+    if (!addr) {
+        return s;
+    }
 
     addr->sat_family = AF_APPLETALK;
+
     /* rest of address should be initialized by the caller */
-    if (bind(s, (struct sockaddr *) addr, sizeof( struct sockaddr_at )) < 0 ) {
+    if (bind(s, (struct sockaddr *) addr, sizeof(struct sockaddr_at)) < 0) {
         close(s);
-	return -1;
+        return -1;
     }
 
     /* get the real address from the kernel */
-    len = sizeof( struct sockaddr_at);
-    if ( getsockname( s, (struct sockaddr *) addr, &len ) != 0 ) {
+    len = sizeof(struct sockaddr_at);
+
+    if (getsockname(s, (struct sockaddr *) addr, &len) != 0) {
         close(s);
-	return -1;
+        return -1;
     }
 
     return s;
